From 2f16c17b683655fe318a1e6d45aaad3857d1a512 Mon Sep 17 00:00:00 2001
From: "Timur I. Bakeyev" <timur@FreeBSD.org>
Date: Mon, 31 May 2021 00:35:36 +0200
Subject: [PATCH 14/28] Add option to disable CTDB tests - failing on FreeBSD
 right now in too many places.

Signed-off-by: Timur I. Bakeyev <timur@FreeBSD.org>
---
 ctdb/wscript | 24 ++++++++++++++++++------
 1 file changed, 18 insertions(+), 6 deletions(-)

diff --git a/ctdb/wscript b/ctdb/wscript
index a9fef9241aa..c89c6decdd7 100644
--- a/ctdb/wscript
+++ b/ctdb/wscript
@@ -106,6 +106,9 @@ def options(opt):
     opt.add_option('--enable-ceph-reclock',
                    help=("Enable Ceph CTDB recovery lock helper (default=no)"),
                    action="store_true", dest='ctdb_ceph_reclock', default=False)
+    opt.add_option('--disable-ctdb-tests',
+                   help=("Disable CTDB tests (default=no)"),
+                   action="store_true", dest='ctdb_no_tests', default=False)
 
     opt.add_option('--with-logdir',
                    help=("Path to log directory"),
@@ -278,7 +281,7 @@ def configure(conf):
 
     if Options.options.ctdb_ceph_reclock:
         if (conf.CHECK_HEADERS('rados/librados.h', False, False, 'rados') and
-					conf.CHECK_LIB('rados', shlib=True)):
+                                         conf.CHECK_LIB('rados', shlib=True)):
             Logs.info('Building with Ceph librados recovery lock support')
             conf.define('HAVE_LIBRADOS', 1)
         else:
@@ -317,8 +320,14 @@ def configure(conf):
                     conf.env.CTDB_VARDIR,
                     conf.env.CTDB_RUNDIR))
 
-    conf.env.CTDB_TEST_DATADIR = os.path.join(conf.env.CTDB_DATADIR, 'tests')
-    conf.env.CTDB_TEST_LIBEXECDIR = os.path.join(conf.env.LIBEXECDIR, 'ctdb/tests')
+    if Options.options.ctdb_no_tests:
+        conf.env.ctdb_tests = False
+    else:
+        conf.env.ctdb_tests = True
+
+    if conf.env.ctdb_tests:
+        conf.env.CTDB_TEST_DATADIR = os.path.join(conf.env.CTDB_DATADIR, 'tests')
+        conf.env.CTDB_TEST_LIBEXECDIR = os.path.join(conf.env.LIBEXECDIR, 'ctdb/tests')
 
     # Allow unified compilation and separate compilation of utilities
     # to find includes
@@ -706,9 +715,9 @@ def build(bld):
     if bld.env.HAVE_LIBRADOS:
         bld.SAMBA_BINARY('ctdb_mutex_ceph_rados_helper',
                          source='utils/ceph/ctdb_mutex_ceph_rados_helper.c',
-			 deps='talloc tevent rados',
-			 includes='include',
-			 install_path='${CTDB_HELPER_BINDIR}')
+                         deps='talloc tevent rados',
+                         includes='include',
+                         install_path='${CTDB_HELPER_BINDIR}')
 
     sed_expr1 = 's|/usr/local/var/lib/ctdb|%s|g'  % (bld.env.CTDB_VARDIR)
     sed_expr2 = 's|/usr/local/etc/ctdb|%s|g'      % (bld.env.CTDB_ETCDIR)
@@ -885,6 +894,9 @@ def build(bld):
     for d in ['volatile', 'persistent', 'state']:
         bld.INSTALL_DIR(os.path.join(bld.env.CTDB_VARDIR, d))
 
+    if not bld.env.ctdb_tests:
+        return
+
     #
     # Test-only below this point
     #
-- 
2.37.1

